@@ -65,7 +65,7 @@ import java.util.Map;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Executor;
 import java.util.concurrent.Future;
-import org.apache.commons.logging.Log;
+import javax.mail.MessagingException;
 import com.openexchange.context.ContextService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
@@ -83,7 +83,10 @@ import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.api.MailMessageStorage;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
+import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.search.SearchTerm;
+import com.openexchange.mail.threader.Conversation;
+import com.openexchange.mail.threader.Conversations;
 import com.openexchange.mail.utils.MailMessageComparator;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
@@ -94,6 +97,7 @@ import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.unifiedinbox.copy.UnifiedInboxMessageCopier;
 import com.openexchange.unifiedinbox.dataobjects.UnifiedMailMessage;
+import com.openexchange.unifiedinbox.services.UnifiedInboxServiceRegistry;
 import com.openexchange.unifiedinbox.utility.LoggingCallable;
 import com.openexchange.unifiedinbox.utility.TrackingCompletionService;
 import com.openexchange.unifiedinbox.utility.UnifiedInboxCompletionService;
@@ -107,8 +111,7 @@ import com.openexchange.user.UserService;
  */
 public final class UnifiedInboxMessageStorage extends MailMessageStorage implements ISimplifiedThreadStructure {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(UnifiedInboxMessageStorage.class);
-    private static final boolean DEBUG = LOG.isDebugEnabled();
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(UnifiedInboxMessageStorage.class);
 
     /*-
      * Members
@@ -182,6 +185,11 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
         return accounts;
     }
 
+    private MailAccount getAccount(final int accountId) throws OXException {
+        final MailAccountStorageService srv = UnifiedInboxServiceRegistry.getServiceRegistry().getService(MailAccountStorageService.class);
+        return srv.getMailAccount(accountId, user, cid);
+    }
+
     @Override
     public void releaseResources() throws OXException {
         // Nothing to release
@@ -263,7 +271,7 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                                 }
                             }
                         } catch (final OXException e) {
-                            getLogger().debug(e.getMessage(), e);
+                            getLogger().debug("", e);
                             return GetMessagesResult.EMPTY_RESULT;
                         } finally {
                             closeSafe(mailAccess);
@@ -310,10 +318,8 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                     final GetMessagesResult result = completionService.take().get();
                     insertMessage(mailIds, messages, result.accountId, result.folder, result.mails, fullName, undelegatedAccountId);
                 }
-                if (DEBUG) {
-                    LOG.debug(new StringBuilder(64).append("Retrieval of ").append(mailIds.length).append(" messages from folder \"").append(
-                        fullName).append("\" took ").append(completionService.getDuration()).append("msec."));
-                }
+                LOG.debug("Retrieval of {} messages from folder \"{}\" took {}msec.", mailIds.length, fullName, completionService.getDuration());
+
             } catch (final InterruptedException e) {
                 Thread.currentThread().interrupt();
                 throw MailExceptionCode.INTERRUPT_ERROR.create(e);
@@ -581,10 +587,8 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                 for (int i = 0; i < length; i++) {
                     messages.addAll(completionService.take().get());
                 }
-                if (DEBUG) {
-                    LOG.debug(new StringBuilder(64).append("getThreadSortedMessages from folder \"").append(fullName).append("\" took ").append(
-                        completionService.getDuration()).append("msec."));
-                }
+                LOG.debug("getThreadSortedMessages from folder \"{}\" took {}msec.", fullName, completionService.getDuration());
+
                 // Sort them
                 final MailMessageComparator comparator = new MailMessageComparator(effectiveSortField, descending, null);
                 final Comparator<List<MailMessage>> listComparator = new Comparator<List<MailMessage>>() {
@@ -634,7 +638,7 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
             mailAccess.connect();
             // Get account's messages
             final IMailMessageStorage messageStorage = mailAccess.getMessageStorage();
-            if (messageStorage instanceof ISimplifiedThreadStructure) {
+            if ((messageStorage instanceof ISimplifiedThreadStructure)) {
                 try {
                     return ((ISimplifiedThreadStructure) messageStorage).getThreadSortedMessages(fa.getFullname(), includeSent, false, indexRange, max, sortField, order, mailFields);
                 } catch (final OXException e) {
@@ -645,94 +649,147 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                 }
             }
             /*-
-             * 1. Send 'all' request with id, folder_id, level, and received_date - you need all that data.
+             * --------------------------------------------------------------------------------------------------------------------------
              *
-             * 2. Whenever level equals 0, a new thread starts (new array)
+             * Manually do thread-sort
              *
-             * 3. Add all objects (id, folder_id, received_date) to that list until level !== 0.
-             *
-             * 4. Order by received_date (ignore the internal level structure), so that the newest mails show up first.
-             *
-             * 5. Generate the real list of all threads. This must be again ordered by received_date, so that the most recent threads show up
-             *    first. id and folder_id refer to the most recent mail.
+             * Sort by references
              */
-            MailMessage[] msgArr;
-            try {
-                final int allSort = MailSortField.RECEIVED_DATE.getField();
-                final int allOrder = OrderDirection.DESC.getOrder();
-                msgArr = messageStorage.getThreadSortedMessages(fullName, indexRange, sortField, order, null, mailFields);
-            } catch (final OXException e) {
-                msgArr = messageStorage.getAllMessages(fullName, indexRange, sortField, order, mailFields);
-            }
-            List<List<MailMessage>> list = new LinkedList<List<MailMessage>>();
-            List<MailMessage> current = new LinkedList<MailMessage>();
-            // Here we go
-            final int size = msgArr.length;
-            for (int i = 0; i < size; i++) {
-                final MailMessage mail = msgArr[i];
-                final int threadLevel = mail.getThreadLevel();
-                if (0 == threadLevel) {
-                    list.add(current);
-                    current = new LinkedList<MailMessage>();
-                }
-                current.add(mail);
-            }
-            list.add(current);
-            /*
-             * Sort empty ones
-             */
-            for (final Iterator<List<MailMessage>> iterator = list.iterator(); iterator.hasNext();) {
-                final List<MailMessage> mails = iterator.next();
-                if (null == mails || mails.isEmpty()) {
-                    iterator.remove();
-                } else {
-                    Collections.sort(mails, COMPARATOR);
-                }
-            }
-            /*
-             * Sort root elements
-             */
-            final boolean descending = OrderDirection.DESC.equals(order);
-            MailSortField effectiveSortField = null == sortField ? MailSortField.RECEIVED_DATE :  sortField;
-            if (null == effectiveSortField) {
-                effectiveSortField = MailSortField.RECEIVED_DATE;
-            }
-            final MailMessageComparator comparator = new MailMessageComparator(effectiveSortField, descending, null);
-            final Comparator<List<MailMessage>> listComparator = new Comparator<List<MailMessage>>() {
+            final String realFullName = fa.getFullname();
+            final boolean mergeWithSent = includeSent && !mailAccess.getFolderStorage().getSentFolder().equals(realFullName);
+            final Future<List<MailMessage>> messagesFromSentFolder;
+            if (mergeWithSent) {
+                final String sentFolder = mailAccess.getFolderStorage().getSentFolder();
+                messagesFromSentFolder = ThreadPools.getThreadPool().submit(new AbstractTask<List<MailMessage>>() {
 
-                @Override
-                public int compare(final List<MailMessage> o1, final List<MailMessage> o2) {
-                    return comparator.compare(o1.get(0), o2.get(0));
+                    @Override
+                    public List<MailMessage> call() throws Exception {
+                        return Conversations.messagesFor(sentFolder, (int) max, new MailFields(mailFields), messageStorage);
+                    }
+                });
+            } else {
+                messagesFromSentFolder = null;
+            }
+            // For actual folder
+            final List<Conversation> conversations = Conversations.conversationsFor(realFullName, (int) max, new MailFields(mailFields), messageStorage);
+            // Retrieve from sent folder
+            if (null != messagesFromSentFolder) {
+                final List<MailMessage> sentMessages = getFrom(messagesFromSentFolder);
+                for (final Conversation conversation : conversations) {
+                    for (final MailMessage sentMessage : sentMessages) {
+                        if (conversation.referencesOrIsReferencedBy(sentMessage)) {
+                            conversation.addMessage(sentMessage);
+                        }
+                    }
                 }
-            };
-            Collections.sort(list, listComparator);
+            }
+            // Fold it
+            Conversations.fold(conversations);
+            // Comparator
+            final MailMessageComparator threadComparator = COMPARATOR;
+            // Sort
+            List<List<MailMessage>> list = new ArrayList<List<MailMessage>>(conversations.size());
+            for (final Conversation conversation : conversations) {
+                list.add(conversation.getMessages(threadComparator));
+            }
+            // Sort root elements
+            {
+                final MailSortField effectiveSortField = null == sortField ? MailSortField.RECEIVED_DATE :  sortField;
+                final Comparator<List<MailMessage>> listComparator = getListComparator(effectiveSortField, order, getLocale());
+                Collections.sort(list, listComparator);
+            }
+            // Check for index range
             if (null != indexRange) {
                 final int fromIndex = indexRange.start;
                 int toIndex = indexRange.end;
-                final int lsize = list.size();
-                if ((fromIndex) > lsize) {
-                    /*
-                     * Return empty iterator if start is out of range
-                     */
+                final int size = list.size();
+                if ((fromIndex) > size) {
+                    // Return empty iterator if start is out of range
                     return Collections.emptyList();
                 }
-                /*
-                 * Reset end index if out of range
-                 */
-                if (toIndex >= lsize) {
-                    toIndex = lsize;
+                // Reset end index if out of range
+                if (toIndex >= size) {
+                    toIndex = size;
                 }
                 list = list.subList(fromIndex, toIndex);
             }
             /*
-             * Finally return
+             * Apply account identifier
              */
+            setAccountInfo2(list, getAccount(fa.getAccountId()));
+            // Return list
             return list;
         } finally {
             closeSafe(mailAccess);
         }
     }
 
+    private static <T> T getFrom(final Future<T> f) throws OXException {
+        if (null == f) {
+            return null;
+        }
+        try {
+            return f.get();
+        } catch (final InterruptedException e) {
+            Thread.currentThread().interrupt(); // Keep interrupted state
+            throw MailExceptionCode.INTERRUPT_ERROR.create(e, e.getMessage());
+        } catch (final ExecutionException e) {
+            final Throwable cause = e.getCause();
+            if (cause instanceof MessagingException) {
+                throw MimeMailException.handleMessagingException((MessagingException) cause);
+            }
+            throw ThreadPools.launderThrowable(e, OXException.class);
+        }
+
+    }
+
+    private Comparator<List<MailMessage>> getListComparator(final MailSortField sortField, final OrderDirection order, final Locale locale) {
+        final MailMessageComparator comparator = new MailMessageComparator(sortField, OrderDirection.DESC.equals(order), locale);
+        final Comparator<List<MailMessage>> listComparator = new Comparator<List<MailMessage>>() {
+
+            @Override
+            public int compare(final List<MailMessage> o1, final List<MailMessage> o2) {
+                int result = comparator.compare(o1.get(0), o2.get(0));
+                if ((0 != result) || (MailSortField.RECEIVED_DATE != sortField)) {
+                    return result;
+                }
+                // Zero as comparison result AND primarily sorted by received-date
+                final MailMessage msg1 = o1.get(0);
+                final MailMessage msg2 = o2.get(0);
+                final String inReplyTo1 = msg1.getInReplyTo();
+                final String inReplyTo2 = msg2.getInReplyTo();
+                if (null == inReplyTo1) {
+                    result = null == inReplyTo2 ? 0 : -1;
+                } else {
+                    result = null == inReplyTo2 ? 1 : 0;
+                }
+                return 0 == result ? new MailMessageComparator(MailSortField.SENT_DATE, OrderDirection.DESC.equals(order), null).compare(msg1, msg2) : result;
+            }
+        };
+        return listComparator;
+    }
+
+    /**
+     * Sets account ID and name in given instances of {@link MailMessage}.
+     *
+     * @param mailMessages The {@link MailMessage} instances
+     * @return The given instances of {@link MailMessage} each with account ID and name set
+     * @throws OXException If mail account cannot be obtained
+     */
+    private <C extends Collection<MailMessage>, W extends Collection<C>> W setAccountInfo2(final W col, final MailAccount account) throws OXException {
+        final String name = account.getName();
+        final int id = account.getId();
+        for (final C mailMessages : col) {
+            for (final MailMessage mailMessage : mailMessages) {
+                if (null != mailMessage) {
+                    mailMessage.setAccountId(id);
+                    mailMessage.setAccountName(name);
+                }
+            }
+        }
+        return col;
+    }
+
     @Override
     public MailMessage[] getThreadSortedMessages(final String fullName, final IndexRange indexRange, final MailSortField sortField, final OrderDirection order, final SearchTerm<?> searchTerm, final MailField[] fields) throws OXException {
         if (DEFAULT_FOLDER_ID.equals(fullName)) {
@@ -805,10 +862,8 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                 for (int i = 0; i < length; i++) {
                     messages.addAll(completionService.take().get());
                 }
-                if (DEBUG) {
-                    LOG.debug(new StringBuilder(64).append("Searching messages from folder \"").append(fullName).append("\" took ").append(
-                        completionService.getDuration()).append("msec."));
-                }
+                LOG.debug("Searching messages from folder \"{}\" took {}msec.", fullName, completionService.getDuration());
+
                 // Sort them
                 final MailMessageComparator c = new MailMessageComparator(sortField, OrderDirection.DESC.equals(order), getLocale());
                 Collections.sort(messages, c);
@@ -934,10 +989,7 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                 for (int i = 0; i < length; i++) {
                     messages.addAll(completionService.take().get());
                 }
-                if (DEBUG) {
-                    LOG.debug(new StringBuilder(64).append("Searching messages from folder \"").append(fullName).append("\" took ").append(
-                        completionService.getDuration()).append("msec."));
-                }
+                LOG.debug("Searching messages from folder \"{}\" took {}msec.", fullName, completionService.getDuration());
                 // Sort them
                 final MailMessageComparator c = new MailMessageComparator(effectiveSortField, OrderDirection.DESC.equals(order), getLocale());
                 Collections.sort(messages, c);
@@ -1031,7 +1083,7 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                             }
                             return messages;
                         } catch (final OXException e) {
-                            getLogger().debug(e.getMessage(), e);
+                            getLogger().debug("", e);
                             return Collections.emptyList();
                         } finally {
                             closeSafe(mailAccess);
@@ -1045,10 +1097,8 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                 for (int i = 0; i < length; i++) {
                     messages.addAll(completionService.take().get());
                 }
-                if (DEBUG) {
-                    LOG.debug(new StringBuilder(64).append("Retrieving unread messages from folder \"").append(fullName).append("\" took ").append(
-                        completionService.getDuration()).append("msec."));
-                }
+                LOG.debug("Retrieving unread messages from folder \"{}\" took {}msec.", fullName, completionService.getDuration());
+
                 // Sort them
                 Collections.sort(messages, new MailMessageComparator(sortField, OrderDirection.DESC.equals(order), getLocale()));
                 // Return as array
@@ -1114,7 +1164,7 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                                 mailAccess.getMessageStorage().deleteMessages(folder, uids.toArray(new String[uids.size()]), hardDelete);
                             }
                         } catch (final OXException e) {
-                            getLogger().debug(e.getMessage(), e);
+                            getLogger().debug("", e);
                             return null;
                         } finally {
                             closeSafe(mailAccess);
@@ -1126,15 +1176,8 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
             final ThreadPoolService executor = ThreadPools.getThreadPool();
             try {
                 // Invoke all and wait for being executed
-                if (DEBUG) {
-                    final long start = System.currentTimeMillis();
-                    executor.invokeAll(collection);
-                    final long dur = System.currentTimeMillis() - start;
-                    LOG.debug(new StringBuilder(64).append("Deleting ").append(mailIds.length).append(" messages in folder \"").append(
-                        fullName).append(" took ").append(dur).append("msec."));
-                } else {
-                    executor.invokeAll(collection);
-                }
+                executor.invokeAll(collection);
+
             } catch (final InterruptedException e) {
                 Thread.currentThread().interrupt();
                 throw MailExceptionCode.INTERRUPT_ERROR.create(e);
@@ -1215,7 +1258,7 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                                 mailAccess.getMessageStorage().updateMessageFlags(folder, uids.toArray(new String[uids.size()]), flags, set);
                             }
                         } catch (final OXException e) {
-                            getLogger().debug(e.getMessage(), e);
+                            getLogger().debug("", e);
                             return null;
                         } finally {
                             closeSafe(mailAccess);
@@ -1227,15 +1270,8 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
             final ThreadPoolService executor = ThreadPools.getThreadPool();
             try {
                 // Invoke all and wait for being executed
-                if (DEBUG) {
-                    final long start = System.currentTimeMillis();
-                    executor.invokeAll(collection);
-                    final long dur = System.currentTimeMillis() - start;
-                    LOG.debug(new StringBuilder(64).append("Updating system/user flags of ").append(mailIds.length).append(
-                        " messages took ").append(dur).append("msec."));
-                } else {
-                    executor.invokeAll(collection);
-                }
+                executor.invokeAll(collection);
+
             } catch (final InterruptedException e) {
                 Thread.currentThread().interrupt();
                 throw MailExceptionCode.INTERRUPT_ERROR.create(e);
@@ -1291,7 +1327,7 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
                                     colorLabel);
                             }
                         } catch (final OXException e) {
-                            getLogger().debug(e.getMessage(), e);
+                            getLogger().debug("", e);
                             return null;
                         } finally {
                             closeSafe(mailAccess);
@@ -1303,15 +1339,8 @@ public final class UnifiedInboxMessageStorage extends MailMessageStorage impleme
             final ThreadPoolService executor = ThreadPools.getThreadPool();
             try {
                 // Invoke all and wait for being executed
-                if (DEBUG) {
-                    final long start = System.currentTimeMillis();
-                    executor.invokeAll(collection);
-                    final long dur = System.currentTimeMillis() - start;
-                    LOG.debug(new StringBuilder(64).append("Updating color flag of ").append(mailIds.length).append(" messages took ").append(
-                        dur).append("msec."));
-                } else {
-                    executor.invokeAll(collection);
-                }
+                executor.invokeAll(collection);
+
             } catch (final InterruptedException e) {
                 Thread.currentThread().interrupt();
                 throw MailExceptionCode.INTERRUPT_ERROR.create(e);
