@@ -61,7 +61,7 @@ import com.openexchange.mail.config.MailProperties;
  */
 public final class UnifiedInboxProperties extends AbstractProtocolProperties implements IUnifiedInboxProperties {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(UnifiedInboxProperties.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(UnifiedInboxProperties.class);
 
     private static final UnifiedInboxProperties instance = new UnifiedInboxProperties();
 
@@ -89,9 +89,7 @@ public final class UnifiedInboxProperties extends AbstractProtocolProperties imp
         final StringBuilder logBuilder = new StringBuilder(1024);
         logBuilder.append("\nLoading global Unified Mail properties...\n");
         logBuilder.append("Global Unified Mail properties successfully loaded!");
-        if (LOG.isInfoEnabled()) {
-            LOG.info(logBuilder.toString());
-        }
+        LOG.info(logBuilder.toString());
     }
 
     @Override
